==> n2o-config-7.29.0-sources.jar: net/n2oapp/framework/config/metadata/compile/control/MaskedInputCompiler.java <==
package net.n2oapp.framework.config.metadata.compile.control;

import net.n2oapp.framework.api.metadata.Source;
import net.n2oapp.framework.api.metadata.compile.CompileContext;
import net.n2oapp.framework.api.metadata.compile.CompileProcessor;
import net.n2oapp.framework.api.metadata.control.plain.N2oMaskedInput;
import net.n2oapp.framework.api.metadata.domain.DomainEnum;
import net.n2oapp.framework.api.metadata.meta.control.MaskedInput;
import net.n2oapp.framework.api.metadata.meta.control.StandardField;
import org.springframework.stereotype.Component;

import static net.n2oapp.framework.api.metadata.compile.building.Placeholders.property;
import static net.n2oapp.framework.api.metadata.local.util.CompileUtil.castDefault;


/**
 * Компиляция поля с маской для ввода текста
 */
@Component
public class MaskedInputCompiler extends StandardFieldCompiler<MaskedInput, N2oMaskedInput> {

    @Override
    protected String getControlSrcProperty() {
        return "n2o.api.control.masked_input.src";
    }

    @Override
    public Class<? extends Source> getSourceClass() {
        return N2oMaskedInput.class;
    }

    @Override
    public StandardField<MaskedInput> compile(N2oMaskedInput source, CompileContext<?, ?> context, CompileProcessor p) {
        source.setDomain(castDefault(source.getDomain(), DomainEnum.STRING.getName()));
        MaskedInput maskedInput = new MaskedInput();
        maskedInput.setMask(p.resolveJS(source.getMask()));
        maskedInput.setMeasure(source.getMeasure());
        maskedInput.setClassName(source.getCssClass());
        maskedInput.setClearOnBlur(castDefault(source.getClearOnBlur(),
                () -> p.resolve(property("n2o.api.control.masked_input.clear_on_blur"), Boolean.class)));
        return compileStandardField(maskedInput, source, context, p);
    }
}

==> n2o-config-7.29.2-sources.jar: net/n2oapp/framework/config/metadata/compile/control/MaskedInputCompiler.java <==
package net.n2oapp.framework.config.metadata.compile.control;

import net.n2oapp.framework.api.metadata.Source;
import net.n2oapp.framework.api.metadata.compile.CompileContext;
import net.n2oapp.framework.api.metadata.compile.CompileProcessor;
import net.n2oapp.framework.api.metadata.control.plain.N2oMaskedInput;
import net.n2oapp.framework.api.metadata.domain.DomainEnum;
import net.n2oapp.framework.api.metadata.meta.control.MaskedInput;
import net.n2oapp.framework.api.metadata.meta.control.StandardField;
import org.springframework.stereotype.Component;

import static net.n2oapp.framework.api.metadata.compile.building.Placeholders.property;
import static net.n2oapp.framework.api.metadata.local.util.CompileUtil.castDefault;


/**
 * Компиляция поля с маской для ввода текста
 */
@Component
public class MaskedInputCompiler extends StandardFieldCompiler<MaskedInput, N2oMaskedInput> {

    @Override
    protected String getControlSrcProperty() {
        return "n2o.api.control.masked_input.src";
    }

    @Override
    public Class<? extends Source> getSourceClass() {
        return N2oMaskedInput.class;
    }

    @Override
    public StandardField<MaskedInput> compile(N2oMaskedInput source, CompileContext<?, ?> context, CompileProcessor p) {
        source.setDomain(castDefault(source.getDomain(), DomainEnum.STRING.getName()));
        MaskedInput maskedInput = new MaskedInput();
        maskedInput.setMask(p.resolveJS(source.getMask()));
        maskedInput.setMeasure(source.getMeasure());
        maskedInput.setClassName(source.getCssClass());
        maskedInput.setClearOnBlur(castDefault(source.getClearOnBlur(),
                () -> p.resolve(property("n2o.api.control.masked_input.clear_on_blur"), Boolean.class)));
        maskedInput.setAutocomplete(castDefault(source.getAutocomplete(),
                () -> p.resolve(property("n2o.api.control.masked_input.autocomplete"), String.class)));
        return compileStandardField(maskedInput, source, context, p);
    }
}
